# John Larkin - Skills

## Programming Languages

### Experienced
- Python (FastAPI, NumPy, Pandas, Pytest, OpenAI, Langchain, OpenCV, Matplotlib, Seaborn, SQLAlchemy)
- TypeScript / JavaScript (React, Next.js)
- C++ (XGBoost, Armadillo)
- Go
- C#
- T-SQL
- Swift
- Rust
- Ab Initio DML

### Familiar
- JAX (LSTMs, MDNs)
- CSS / HTML
- LaTeX
- R

## Software & Tooling

### Experienced
- Postgres, Neon, Supabase
- ScyllaDB
- Terraform
- k6
- Git
- Docker
- Kubernetes
- AWS (EC2)
- Vercel
- SSMS
- Ab Initio
- Splunk
- Grafana

### Familiar
- DuckDB
- Qdrant (vector DB)
- Tauri
- Vite
- Tailwind CSS
- GraphQL
- Shopify API
- Google Pub/Sub
- Chrome Extension API
- Manim
- Miro / Figma
- TensorFlow, NiceGUI
- MATLAB
- SSIS
- OpenShift
- HDFS

## Domains

### Professional
- Distributed Systems
- Low Latency / High Performance Computing
- Data Processing / ETL Pipelines
- Trading Systems / Fintech
- Cloud Infrastructure (AWS, EKS, Lambda)
- Backend Systems & API Design
- Large-Scale Migrations

### Personal Projects
- Machine Learning / AI (LSTMs, MDNs, RAG, embeddings, optimizers)
- Computer Vision
- Data Visualization
- Full-Stack Web Development
- Desktop Application Development (Tauri)
- Mobile Application Development
- E-commerce Integrations (Shopify)
- Sports Analytics
- Quantum Computing (exploration)
- Numerical Methods
